#!/usr/bin/env python
from badges.badge import Badge

# https://sonarcloud.io/api/project_badges/measure?project=name&metric=key
# metric=bugs                   bugs
# metric=code_smells            code_smells
# metric=sqale_rating           maintainability     (dublicated with codeclimate badge)
# metric=alert_status           Quality Gate        (passed. no need)
# metric=reliability_rating     reliability
# metric=security_rating        security_rating
# metric=sqale_index            Tech debt           (time. no need)
# metric=vulnerabilities        vulnerabilities


class Sonarcloud(Badge):
    title = "Sonarcloud"
    image = "https://sonarcloud.io/api/project_badges/measure?project={project}&metric={metric}"
    link = "https://sonarcloud.io/dashboard?id={project}"

    def __init__(self, project, metric):
        self.project = project
        self.metric = metric
        # todo: validate metric



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://codeclimate.com/github/owner/repo
# https://codeclimate.com/github/owner/repo/badges/gpa.svg


class Codeclimate(GitBadge):
    title = "CodeClimate"
    image = "https://codeclimate.com/github/{fullname}/badges/gpa.svg"
    link = "https://codeclimate.com/github/{fullname}"



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://circleci.com/gh/owner/repo/tree/master
# https://circleci.com/gh/owner/repo/tree/master.svg?style=svg


class Circleci(GitBadge):
    title = "CircleCI"
    image = "https://circleci.com/gh/{fullname}/tree/{branch}.svg?style=svg"
    link = "https://circleci.com/gh/{fullname}/tree/{branch}"



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://codecov.io/gh/owner/repo
# https://codecov.io/gh/owner/repo/branch/master/graph/badge.svg


class Codecov(GitBadge):
    title = "Codecov"
    image = "https://codecov.io/gh/{fullname}/branch/{branch}/graph/badge.svg"
    link = "https://codecov.io/gh/{fullname}"



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://bettercodehub.com/results/owner/repo
# https://bettercodehub.com/edge/badge/owner/repo?branch=master


class Bettercodehub(GitBadge):
    title = "BetterCodeHub"
    image = "https://bettercodehub.com/edge/badge/{fullname}?branch={branch}"
    link = "https://bettercodehub.com/results/{fullname}"



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://semaphoreci.com/api/v1/owner/repo/branches/master/badge.svg
# https://semaphoreci.com/api/v1/owner/repo/branches/master/shields_badge.svg


class Semaphoreci(GitBadge):
    title = "Semaphore CI"

    def __init__(self, fullname, branch="master", shields=True, **kwargs):
        self.update(fullname=fullname, branch=branch, shields=shields, **kwargs)

    @property
    def image(self):
        fullname = self.fullname.replace(".", "-")
        if not self.shields:
            return "https://semaphoreci.com/api/v1/%s/branches/{branch}/badge.svg" % fullname
        return "https://semaphoreci.com/api/v1/%s/branches/{branch}/shields_badge.svg" % fullname

    @property
    def link(self):
        fullname = self.fullname.replace(".", "-")
        return "https://semaphoreci.com/%s" % fullname



#!/usr/bin/env python
from badges.badge import Badge


class GitBadge(Badge):
    def __init__(self, fullname, branch="master", **kwargs):
        self.update(fullname=fullname, branch=branch, **kwargs)



#!/usr/bin/env python
from badges.badge import Badge
from badges.bettercodehub import Bettercodehub
from badges.circleci import Circleci
from badges.codeclimate import Codeclimate
from badges.codecov import Codecov
from badges.codefactor import Codefactor
from badges.scrutinizer import Scrutinizer
from badges.semaphoreci import Semaphoreci
from badges.sonarcloud import Sonarcloud
from badges.travis import Travis



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://www.codefactor.io/repository/github/owner/repo
# https://www.codefactor.io/repository/github/owner/repo/badge


class Codefactor(GitBadge):
    title = "CodeFactor"
    image = "https://www.codefactor.io/repository/github/{fullname}/badge"
    link = "https://www.codefactor.io/repository/github/{fullname}"



#!/usr/bin/env python
from public import public


# format string:
# "a={a}, b={b}, c={c}".format(**vars(obj)) # variables only
# 'a={0.a}, b={0.b}, c={0.c}'.format(obj)


@public
class Badge:
    image = None
    link = ""
    title = ""
    markup = "md"
    branch = "master"

    def __init__(self, **kwargs):
        self.update(**kwargs)

    def update(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)

    def format_string(self, string):
        kwargs = dict()
        kwargs.update(**vars(self))
        kwargs.update(**vars(self.__class__))
        return string.format(self, **kwargs)

    def get_image(self):
        if not self.image:
            raise ValueError("image EMPTY")
        return self.format_string(self.image)

    def get_link(self):
        return self.format_string(self.link or "")

    def get_title(self):
        return self.format_string(self.title or "")

    def render_md(self):
        return "[![%s](%s)](%s)" % (self.get_title(), self.get_image(), self.get_link())

    def render_rst(self):
        target = self.link
        if not self.link:
            target = "none"
        return """.. image: : %s
    : target: %s""" % (self.get_image(), target)

    def render(self, markup):
        if markup == "md":
            return self.render_md()
        if markup == "rst":
            return self.render_rst()
        raise ValueError("'%s' unknown markup" % markup)

    @property
    def visible(self):
        return True

    def __bool__(self):
        return self.visible

    def __nonzero__(self):
        return self.visible

    def __str__(self):
        if self:
            return self.render(self.markup)
        return ""

    def __repr__(self):
        return self.__str__()



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://travis-ci.org/owner/repo
# https://api.travis-ci.org/owner/repo.svg?branch=master


class Travis(GitBadge):
    title = "Travis"
    image = "https://api.travis-ci.org/{fullname}.svg?branch={branch}"
    link = "https://travis-ci.org/{fullname}/"



#!/usr/bin/env python
from badges.gitbadge import GitBadge

# https://github.com/owner/repo
# https://scrutinizer-ci.com/g/owner/repo/
# https://scrutinizer-ci.com/g/owner/repo/badges/quality-score.png?b=master
# https://scrutinizer-ci.com/g/owner/repo/badges/build.png?b=master


class Scrutinizer(GitBadge):
    title = "Scrutinizer"
    link = "https://scrutinizer-ci.com/g/{fullname}/"

    def __init__(self, fullname, branch="master", build=False, **kwargs):
        self.update(fullname=fullname, branch=branch, build=build, **kwargs)

    @property
    def image(self):
        if self.build:
            return "https://scrutinizer-ci.com/g/{fullname}/badges/build.png?b={branch}"
        return "https://scrutinizer-ci.com/g/{fullname}/badges/quality-score.png?b={branch}"
